NAME
    geolinearray - maintain a database of ensembles of geographic points
    
VERSION
    1.2

SYNOPSIS
    geolinearray option arg ?arg ...?

DESCRIPTION
    Creates, catalogs, and destroys geoLineArrays.
    Nomenclature:  A lat-lon pair is a geoPoint.  A set of geoPoints make a
    geoLine.  A set of geoLines make a geoLineArray.
    They are most often used for drawing outlines or for drawing large sets of
    anonymous points.  The legal options are:

    geolinearray fmascii geoLineArray stream
        Loads a set of geoLines from an ascii stream.  GeoLineArray is the
        name of the new set of geoLines.  Stream is the source of coordinates
        for the points.  If the first character in stream's name is '|',
        then it is assumed to be a process whose standard output contains
        the points, otherwise it must be a file.  The stream (file or
        process) must have the following format:

        An integer giving the number of bytes in the character descriptor.
        A character descriptor giving information about the file or
            stream.  There has to be a descriptor.  If you do not want to give
            any information start the stream with something bogus like "1a".
        Then for each geoLine in the geoLineArray:    
            An integer giving the number of points in the geoLine.
            Lat-lon coordinates for each point.  The lat-lon pairs can be
                enclosed in parentheses to improve readability.
        
        For example, a file containing the points to make two boxes might 
        be made like this (using Bourne shell commands):
        
        cat > box << END
            3
            box
            5 (35 -100) (35 -90) (30 -90) (30 -100) (35 -100)
            5 (45 -120) (45 -110) (40 -110) (40 -120) (45 -120)
        END

    geolinearray fmxdr geoLineArray stream
        Loads a set of geoLines from an xdr (external data representation)
        stream.  Xdr is a platform transparent format for storing strings,
        integers, and floats.  See the librpc man page or visit
        http://www.acc.umu.se/~balp/rpcunix/ or similar for more information.
        GeoLineArray is the name of the new set of geoLines.  Stream is
        the source of coordinates for the points.  If the first character in
        stream's name is '|', then it is assumed to be a process whose
        standard output contains the points, otherwise it must be a file.  The
        stream (file or process) must have the following format:

            An xdr string record giving information about the file or stream.  
            Then for each geoLine in the geoLineArray:
                An xdr integer record giving number of points in the geoLine.
                For each point in the geoLine:
                    An xdr float record giving the latitude of the point
                    An xdr float record giving the longitude of the point.

        All numbers in the xdr stream are separate records.  None of the values
        are stored in xdr arrays.

    geolinearray fmlist geoLineArray list
        Creates a geoLineArray from a list.

        List can be a list of geoPoints, in which case the geoLineArray has
        only one geoLine.  For example,
        {{lat0 lon0} {lat1 lon1} {lat2 lon2} {lat3 lon3}}
        would be interpreted as a geoLineArray with only one geoLine of four
        points.
    
        More generally, the list can contain several lists, each of which
        contains the points in a geoLine. For example
        { { {lat00 lon00} {lat01 lon01} {lat02 lon02} {lat03 lon03} } \
              { {lat10 lon10} {lat11 lon11} {lat12 lon12} } }
        has two geoLines, the first with four geoPoints, the second with three.

    geolinearray rm geoLineArray
    geolinearray remove geoLineArray
        Deletes a geoLineArray and frees associated storage.

    geolinearray list
        Sets result to a list of currently loaded geoLineArrays.

    geolinearray limits geoLineArray
        Sets result to (north east south west) limits of the geoLineArray.

    geolinearray cross {line1_lat1 line1_lon1} {line1_lat2 line1_lon2} \
        {line2_lat1 line2_lon1} {line2_lat2 line2_lon2}

        Sets result to great circle intersection of two line segments,
        given two points on each segment.
    
        {line1_lat1 line1_lon1} {line1_lat2 line1_lon2} = two points on 1st line
        {line2_lat1 line2_lon1} {line2_lat2 line2_lon2} = two points on 2nd line

        Great circles intersect at two points.  Result given is the intersection
        closer to the average location of the four points.  If the intersection
        is undefined (i.e. all the points are on the same line), returns
        {FLT_MAX FLT_MAX} where FLT_MAX is the largest possible floating point
        value in the implementation.

    geolinearray containpt geoLineArray geoPoint
        Assume each of the geoLines in geoLineArray is a simple convex polygon.
        Returns 1 if geoPoint is contained in any of these polygons, otherwise
        returns 0.  Behavior is unpredictable if any segment in any of the
        geoLines crosses another segment in the same geoLine.

