NAME
    geomap - draw and interact with geographic maps
    
VERSION
    1.2

SYNOPSIS
    geomap pathName ?options?

STANDARD OPTIONS
    anchor
    borderWidth
    background
    cursor
    font
    relief
    
    See the "options" manual entry for details on the standard
    options.

WIDGET-SPECIFIC OPTIONS
    Name:        width
    Class:        Width
    Command-Line Switch:-width
        
        Specifies a desired window width, in pixels, that the geomap widget
        should request from the window manager.
    
    Name:        height
    Class:        Height
    Command-Line Switch:-height
        
        Specifies a desired window height, in pixels, that the geomap widget
        should request from the window manager.
    
    Name:        scale
    Class:        Scale
    Command-Line Switch:-scale
        
        Specifies map scale in cartographic format, e.g. 1:30000000.
    
    Name:        linecolor
    Class:        Foreground
    Command-Line Switch:-linecolor,-lc
        
        Specifies default color for drawing lines.
    
    Name:        dotsize
    Class:        Dotsize
    Command-Line Switch:-dotsize
        
        Specifies non-negative integer giving default dot size
        
    Name:        dotcolor
    Class:        Foreground
    Command-Line Switch:-dotcolor,-dc
        
        Specifies default dot color.
            
    Name:        bmColor
    Class:        Foreground
    Command-Line Switch:-bmColor,-bc
    
        Specifies default bitmap color.
        
    Name:        textcolor
    Class:        Foreground
    Command-Line Switch:-textcolor,-tc
    
        Specifies default text color.

INTRODUCTION

    The geomap command creates a new window (given by the pathName
    argument) and makes it into a geomap widget.  Additional options,
    described above, may be specified on the command line, or in the
    option database to configure aspects of the geomap such as its
    colors, font, scale, and sizes of objects.  The geomap command
    returns its pathName argument.  At the time this command is invoked,
    there must not exist a window named pathName, but pathName's parent
    must exist.

    Geomap widgets draw and manipulate geographic maps.  Presently they deal
    with two kinds of object.  The simplest is the geoplace, a place name
    associated with a given latitude-longitude.  Widget commands draw dots,
    bitmaps, and text at geoplaces.  The other kind of object is a geolinearray,
    which is an array of geolines with a name.  A geoline is an array of
    latitude-longitude coordinates.  Widget commands connect the dots in the
    geolines of a geolinearray, to create outline maps, or draw dots and bitmaps
    at each point, which can be used in dot-density plots.  See the geoplace and
    geolinearray man pages for information on how to load and manage geoplaces
    and geolinearrays.  Other widget commands select map projection,
    orientation, scale, viewing region, and make conversions between window,
    projection, and geographic (latitude-longitude) coordinates.

    The geomap command internally calls "geoplace updatecmd {pathname update}"
    when the geomap widget is created to ensure timely update whenever there
    is a visible change in the geoplace database.  Refer to the geoplace man
    page for information on the geoplace update command.

WIDGET COMMAND

    pathName bitmap placeName bitmap ?color?
    pathName drawbitmap placeName bitmap ?color?
    pathName DrawBitmap placeName bitmap ?color?
        Draws a bitmap at location corresponding to placeName.
        The place must have been created with the geoplace command.  See the
        geoplace man page for details.  Bitmap may have any of the forms
        acceptable to Tk_GetBitmap. Optional color argument specifies a color
        to use for each of the bitmap pixels whose value is one.  Color may
        have any of the forms accepted by Tk_GetColor and defaults to the
        value given by the bmColor configuration option.

    pathName center ?{lat lon}ORplaceName?
    pathName Center ?{lat lon}ORplaceName?
        Without argument, sets result to center of map as {lat lon}.
        With argument, sets map center as indicated and redraws map window.
        Center can be given as named place or lat-lon coordinates.

    pathname cget option
        Returns the current value of the indicated configuration option.
        Option may have any of the values accepted by the geomap command.
        
    pathName commands
    pathName Commands
        Sets result to a list of all widget commands for geomap widget.

    pathName configure ?option? ?value? ?option value ...?
        Queries or modifies the configuration options of the widget.  If no
        option is specified, returns a list describing all of the available
        options for pathName (see Tk_ConfigureInfo for information on the
        format of this list).  If option is specified with no value, then
        the command returns a list describing the one named option (this
        list will be identical to the corresponding sublist of the value
        returned if no option is specified).  If one or more option-value
        pairs is specified, then the command modifies the given widget
        option(s) to have the given value(s);  in this case the command
        returns an empty string.  Option may have any of the values accepted
        by the geomap command.

    pathName dot placeName ?option value? ?option value?
    pathName drawdot placeName ?option value? ?option value?
    pathName DrawDot placeName ?option value? ?option value?
        Draws a dot at the place identified by placeName.  Place must have been
        created with the geoplace command.  See the geoplace man page for
        details.  The following options are supported:

        -c color
            Specifies a color to use.  Color may have any of the forms
            accepted by Tk_GetColor and defaults to the value given by the
            dotcolor configuration option.
        
        -s dotsize
            Dots are square with edge length in pixels given by dotsize.
            Defaults to the value given by the dotsize configuration option.

    pathName erase placeName
    pathName Erase placeName
        Erases any dot, text and bitmap drawn at a place and removes the
        place from the widget place list.  The place still exists in the
        geoPlace database.

    pathName erasebitmap placeName
    pathName EraseBitmap placeName
        Erases bitmap drawn at placeName.

    pathName erasedot placeName
    pathName EraseDot placeName
        Erases dot drawn at placeName (sets its size to 0).

    pathName eraselines geoLineArray
    pathName EraseLines geoLineArray
        Erases all lines, dots, and bitmaps drawn on geoLineArray.

    pathName erasetext placeName
    pathName EraseText placeName
        Erases text drawn at placeName.

    pathName latlontoproj {lat lon}
    pathName LatLonToProj {lat lon}
        Sets result to projection coordinates {ordinate abscissa}
        corresponding to geographical coordinates {lat lon} in current
        widget projection.

    pathName latlontox {lat lon}
    pathName LatLonToX {lat lon}
        Sets result to X coordinates {x y} in widget window corresponding to
        geographical coordinates {lat lon} in current widget projection.
        
    pathName lines geoLineArray ?option value? ?option value? ...
    pathName drawlines geoLineArray ?option value? ?option value? ...
    pathName DrawLines geoLineArray ?option value? ?option value? ...
        Draws a set of lines in geoLineArray or changes options for a
        set of lines already drawn.  GeoLineArray must have been created with
        the geolinearray command. See the geolinearray man page for details.
        The following options are supported:

        -c color
            Specifies a color to use.  Color may have any of the forms
            accepted by Tk_GetColor and defaults to the value given by the
            linecolor configuration option.

        -h thickness
            Specifies line thickness, in pixels.  If value is "nolines," then
            no lines are drawn through the points comprising the geoLineArray,
            but you can still request a dot or bitmap be drawn at the segment
            ends.  Use "nolines" with a nonzero dotsize or bitmap to draw
            density plots or draw something at an ensemble of anonymous points.
            Default thickness is 1.
        
        -y linestyle
            Specifies a linestyle.  If linestyle not recognized, drawLines
            sets result to a list of known linestyles.
            
        -d dotsize
            Specifies size of dots to draw at the segment ends.  Dots are
            square with edge length in pixels given by dotsize.  Default is 0
            (no dots).

        -b bitmap
            Specifies a bitmap to draw at the segment ends.  Bitmap may have
            any of the forms accepted by Tk_GetBitmap.  Default is "none,"
            meaning do not draw a bitmap.

    pathName listplaces
    pathName ListPlaces
        Sets result to a list of place names where a dot, bitmap, or text
        has been drawn in widget.

    pathName projection ?name? ?arg ...?
    pathName Projection ?name? ?arg ...?
        Without arguments, sets result to information about current widget
        projection.  First word is projection name, followed by projection
        dependent parameters, if any.  With argument, sets the widget
        projection.  The following projections are available:

        CylEqdist ?centerLon?
        CylEqDist ?centerLon?
        cyleqdist ?centerLon?
            Sets widget projection to Cylindrical Equidistant projection.
            Optional argument is reference longitude.  If none given, longitude
            of map center becomes reference longitude.
        
        Mercator ?centerLon?
        mercator ?centerLon?
            Sets widget projection to Mercator.
            Optional argument is reference longitude.  If none given, longitude
            of map center becomes reference longitude.
        
        CylEqArea ?centerLon?
        cyleqarea ?centerLon?
        {Cylindrical Equal Area} ?centerLon?
        {cylindrical equal area} ?centerLon?
            Sets widget projection to Cylindrical Equal Area.
            Optional argument is reference longitude.  If none given, longitude
            of map center becomes reference longitude.
        
        LambertConfConic ?{lat lon}ORplaceName?
        LCC ?{lat lon}ORplaceName?
            Sets widget projection to Lambert Conformal Conic.  Optional
            argument gives reference latitude and longitude.  If none given
            reference latitude is latitude of map center, and reference
            longitude is longitude of map center.

        PolarStereographic N|S
        polarstereographic N|S
        PolarSterGrph N|S
        PSG N|S
            Sets widget projection to polar stereographic.  Argument indicates
            which pole.
        
        Sinusoidal ?centerLon?
        sinusoidal ?centerLon?
            Sets widget projection to Sinusoidal.  Optional argument is
            reference longitude.  If none given, longitude of map center
            becomes reference longitude.

        Orthographic "{lat lon}ORplaceName?
        orthographic "{lat lon}ORplaceName?
            Sets widget projection to Orthographic.  Optional argument gives
            reference point.  If none given, map center becomes reference point.

    pathName projtolatlon {ordinate abscissa}
    pathName ProjToLatLon {ordinate abscissa}
        Sets result to {lat lon} corresponding to given projection coordinates.
        Sets results to {FLT_MAX FLT_MAX} if point is outside projection domain.
        (FLT_MAX is the implementation dependent largest possible float.)

    pathName rotation ?angle?
    pathName Rotation ?angle?
    pathName rot ?angle?
    pathName Rot ?angle?
        Without argument, sets result to widget rotation angle in format 
        "number degrees".  With argument, sets widget rotation angle to 
        specified angle.  Rotation is clockwise.  Default is 0 degrees (north
        is "up").

    pathName shift dx dy
    pathName Shift dx dy
        Shifts the widget pixmap dx pixels to the left and dy pixels down. 
        Newly exposed areas are left blank (i.e. in background color) until
        the next update event.  Use to smoothly move part of the display,
        e.g. when dragging, if redrawing the entire window at each motion
        event would cause jerking (due to slow drawing).

    pathName text placeName string ?option arg? ?option arg?
    pathName Text placeName string ?option arg? ?option arg?
        Writes a text string at placeName.  Place must have been created with
        the geoplace command.  See the geoplace man page for details.  The
        following options are supported:
        
        -c color
            Specifies a color to use.  Color may have any of the forms
            accepted by Tk_GetColor and defaults to the value given by the
            textcolor configuration option.

        -fn fontName
            Specifies the font to use for the text item.  FontName may be any
            string acceptable to Tk_GetFontStruct.  Default is given by font
            configuration option.

        -a anchor
            Anchor tells how to position the text relative to the place.  It
            may have any of the forms accepted by Tk_GetAnchor.  For example,
            if anchorPos is center then the text is centered on the place;  if
            anchorPos is n then the text will be drawn north of the place. 
            Default is given by the anchor configuration option.

    pathName update ?now?
        Requests widget redraw.  Normally waits until tk is idle (about to enter
        its event loop), unless "now" option is present, in which case widget
        redraws immediately.

    pathName xtolatlon {x y}
    pathName XToLatLon {x y}
        Sets result to {lat lon} corresponding to window coordinates {x y}.
        Sets result to {FLT_MAX FLT_MAX} if point is outside projection domain.
        (FLT_MAX is the implementation dependent largest possible float.)

